@@ -16,9 +16,9 @@ $TypeOrder	  = array ( 'flows', 'packets', 'traffic');
  * 0.5  * 576 * 300 = 86400 => 1 day
  * $scale * 172800 = time range of graph
  */
-$WinSizeScale  = array ( 0.25,		  0.5,	   1,		 2,		   3.5,		 7,	      14);
+$WinSizeScale  = array ( 0.25, 0.5, 1, 2, 3.5, 7, 15, 30, 90, 120, 183 );
 // labels of the scale selector
-$WinSizeLabels = array ( '12 Hours', '1 day', '2 days', '4 days', '1 week', '2 weeks', '1 month' );
+$WinSizeLabels = array ( '12 Hours', '1 day', '2 days', '4 days', '1 week', '2 weeks', '1 month', '2 months', '6 months', '8 months', '1 year' );
 
 // Definitions for the netflow processing table
 $TopNOption   = array ( 10, 20, 50, 100, 200, 500);
@@ -42,7 +42,7 @@ $IPStatArg	  = array ( '-s record',
 $IPStatOrder  = array ( 'flows', 'packets', 'bytes', 'pps', 'bps', 'bpp' );
 $LimitScale	  = array ( '-', 'K', 'M', 'G', 'T' );
 
-$OutputFormatOption = array ( 'line', 'long', 'extended');
+$OutputFormatOption = array ( 'auto', 'line', 'long', 'extended');
 
 
 function TimeSlotUpdate ($detail_opts) {
@@ -482,6 +482,12 @@ function Process_Details_tab ($tab_changed, $profile_changed) {
 							  	  "allow_null" => 0,
 							  	  "match" => range(0, count($ListNOption)-1) , 
 							  	  "validate" => NULL),
+		"aggr_bidir" 	=> array( "required" => 0, 
+							  	  "default"  => array_key_exists('aggr_bidir', $process_form) ?
+										$process_form['aggr_bidir'] : '',
+							  	  "allow_null" => 0,
+							  	  "match" => array( '', 'checked' ),
+							  	  "validate" => NULL),
 		"aggr_proto" 	=> array( "required" => 0, 
 							  	  "default"  => array_key_exists('aggr_proto', $process_form) ?
 										$process_form['aggr_proto'] : '',
@@ -550,10 +556,10 @@ function Process_Details_tab ($tab_changed, $profile_changed) {
 							  	  "validate" => NULL),
 		"output" 		=> array( "required" => 0, 
 							  	  "default"  => array_key_exists('output', $process_form) ?
-										$process_form['output'] : 'long',
+										$process_form['output'] : 'auto',
 							  	  "allow_null" => 0,
 							  	  "match" => array_key_exists('formatlist', $_SESSION) ? 
-										array_keys($_SESSION['formatlist']) : array('long'),
+										array_keys($_SESSION['formatlist']) : array('auto'),
 							  	  "validate" => NULL),
 		"customfmt" 	=> array( "required" => 0, 
 							  	  "default"  => array_key_exists('customfmt', $process_form) ?
@@ -1381,6 +1387,8 @@ function DisplayProcessing() {
 			<tr id="AggregateRow" <?php echo $formatselect_display_opts?>>
 				<td class='TDnfprocLabel'>Aggregate</td>
 				<td class='TDnfprocControl'>
+					<input type="checkbox" name="aggr_bidir" id="aggr_bidir" value="checked" onClick="ToggleAggregate();"
+						style="margin-left:1" <?php echo $process_form['aggr_bidir'];?>>&nbsp;bi-directional<br>
 					<input type="checkbox" name="aggr_proto" id="aggr_proto" value="checked" 
 						style="margin-left:1" <?php echo $process_form['aggr_proto'];?>>&nbsp;proto<br>
 					<input type="checkbox" name="aggr_srcport" id="aggr_srcport" value="checked" 
@@ -1532,7 +1540,7 @@ function DisplayProcessing() {
 <div id="lookupbox">
 	<div id="lookupbar" align="right" style="background-color:olivedrab"><img src="icons/close.png"
 		onmouseover="this.style.cursor='pointer';" onClick="hidelookup()" title="Close lookup box"></div>
-	<iframe id="cframe" src="" frameborder="0" width=100% height=100%></iframe>
+	<iframe id="cframe" src="" frameborder="0" scrolling="auto" width="100%" height="156"></iframe>
 </div>
 
 
