@@ -39,10 +39,10 @@
 // The very first function to call
 session_start();
 
-$expexted_version = "1.3.1";
+$expexted_version = "1.3.5";
 
 // Session check
-if ( !array_key_exists('version', $_SESSION ) || $_SESSION['version'] !=  $expexted_version ) {
+if ( !array_key_exists('backend_version', $_SESSION ) || $_SESSION['backend_version'] !=  $expexted_version ) {
 	session_destroy();
 	session_start();
 	$_SESSION['version'] = $expexted_version;
@@ -652,6 +652,7 @@ if ( !is_array($out_list) ) {
 foreach ( $out_list['globals'] as $global ) {
 	eval($global);
 }
+$_SESSION['backend_version'] = $version;
 
 // check disk usage
 nfsend_query("get-du", array(), 0);
@@ -695,7 +696,7 @@ switch ($label) {
 		}
 		if ( count($plugins) > 0 ) {
 			$plugin_name = $plugins[ $_SESSION['sub_tab'] ];
-			$include_file = "$FRONTEND_PLUGINDIR/$plugin_name" . ".php";
+			$include_file = "plugins/$plugin_name" . ".php";
 			include($include_file);
 			$plugin_parse_input = $plugin_name . "_ParseInput";
 			$plugin_run 	    = $plugin_name . "_Run";
