@@ -53,18 +53,22 @@ function EditChannel ($is_live_profile, $new_channel, $channelinfo, $liveprofile
 		
 	// compile available source list
 	foreach ( $liveprofile['channel'] as $key => $value ) {
-		$available[$key] = $key;
+		$_tmp[$key] = $key;
 	}
-	sort($available);
 
-	// remove configured sources - remaining sources in $available
+	// remove configured sources - remaining sources in $_tmp
 	$sourcelist = array();
 	if ( !is_null($channelinfo['sourcelist']) ) {
-		$sourcelist = explode('|', $channelinfo['sourcelist']);	
+		$sourcelist = explode('|', $channelinfo['sourcelist']);
 		foreach ( $sourcelist as $key ) {
-				unset($available[$key]);
+			if ( array_key_exists($key, $_tmp) ) {
+				unset($_tmp[$key]);
+			} 
 		}
 	}
+
+	$available = array_keys($_tmp);
+	sort($available);
 	sort($sourcelist);
 ?>
 
@@ -173,8 +177,8 @@ function EditChannel ($is_live_profile, $new_channel, $channelinfo, $liveprofile
 					<td>
 						<select multiple size="6" name="configured[]" id="channel_sources" style="width:100%">
 <?php 
-				for ( $j=0; $j < count($sourcelist); $j++ ) {
-					print "<option value='$sourcelist[$j]'>" . $sourcelist[$j] . "</option>\n";
+				foreach ( $sourcelist as $key ) {
+					print "<option value='$key'>" . $key . "</option>\n";
 				}
 ?>
 						</select>				
@@ -236,10 +240,10 @@ function PrintChannelStat ($is_live_profile, $i, $channelinfo, $visible ) {
 			<th class="CHANNELLIST" colspan="5">
 				<a href="#null" onclick="ShowHide('<?php echo $chan_id;?>')" id="<?php echo $chan_id . 'r';?>" 
 					title="show channel" <?php echo $arrow_style?> ><IMG SRC="icons/arrow.blue.right.png" 
-					name="<php ?echo $chan_id;?> right" border="0" alt="arrow right"></a>
+					name="<?php echo $chan_id;?> right" border="0" alt="arrow right"></a>
 				<a href="#null" onclick="ShowHide('<?php echo $chan_id;?>')" <?php echo $display_style?> id="<?php echo $chan_id . 'd';?>" 
 					title="hide channel"><IMG SRC="icons/arrow.blue.down.png" 
-					name="<php ?echo $chan_id;?> down" border="0" alt="arrow down"></a>	
+					name="<?php echo $chan_id;?> down" border="0" alt="arrow down"></a>	
 				<?php echo $chan_name;?>
 			</th>
 			<th class="CHANNELLIST" style="text-align:right" >
@@ -328,9 +332,15 @@ function ProfileDialog ( ) {
 	$can_add_channel = $status == 'new' || $status == 'stalled' || ($status == 'OK' && ($_SESSION['profileinfo']['type'] & 2) > 0 );
 
 	if ( preg_match("/built (\d+\.{0,1}\d*)/", $status, $matches) ) {
-		$progress = $matches[1];
-	} else 
-		$progress = NULL;
+		$progress   = $matches[1];
+		$opt_cancel = array_key_exists('cancel-inprogress', $_SESSION) ? 0 : 1;
+	} else {
+		$progress   = NULL;
+		$opt_cancel = 0;
+		if ( array_key_exists('cancel-inprogress', $_SESSION) ) {
+			unset($_SESSION['cancel-inprogress']);
+		}
+	}
 
 	$expire = ExpireString($_SESSION['profileinfo']['expire']);
 
@@ -362,6 +372,12 @@ function ProfileDialog ( ) {
     	<input type="image" name="deleteprofile" value="<?php echo $_SESSION['profileswitch']?>" title="Delete this profile" src="icons/trash.png" align="right" >
 		<input type="hidden" name="switch" value="<?php echo $_SESSION['profileswitch']?>" >
 	</form>
+<?php } if ( $opt_cancel ) { ?>
+	<form style="display:inline;" name="profileform" id="profileform" action="<?php  echo $self;?>" method="POST" 
+		onSubmit="return ConfirmCancelBuild(<?php print '\'' . $_SESSION['profile'] . '\', \'' . $_SESSION['profilegroup'] . '\''; ?>);">
+    	<input type="image" name="cancelbuild" value="<?php echo $_SESSION['profileswitch']?>" title="Cancel building profile" src="icons/cancel.png" align="right" >
+		<input type="hidden" name="switch" value="<?php echo $_SESSION['profileswitch']?>" >
+	</form>
 <?php }
 
 	if ( !is_null($progress) ) 
@@ -575,8 +591,8 @@ Ex. 72, 72h, 4d 12h, 14days etc.', this, event, '200px')"><IMG SRC="icons/help.p
 		<input type="image" name="add_channel" value="add_channel" title="Add new channel" src="icons/plus.png" align="right">
 		</form>
 <?php } ?>
-		<a href="#null" onclick="ToggleAll('show')" id="all_r" title="expand channel list" <?php echo $style_arrow_right;?>><IMG SRC="icons/arrow.yellow.right.png" name="<php ?echo $chan_id;?> right" border="0" alt="arrow right"></a>
-		<a href="#null" onclick="ToggleAll('hide')" id="all_d" title="collaps channel list"<?php echo $style_arrow_down;?>><IMG SRC="icons/arrow.yellow.down.png" name="<php ?echo $chan_id;?> down" border="0" alt="arrow down"></a>	
+		<a href="#null" onclick="ToggleAll('show')" id="all_r" title="expand channel list" <?php echo $style_arrow_right;?>><IMG SRC="icons/arrow.yellow.right.png" name="<?php echo $chan_id;?> right" border="0" alt="arrow right"></a>
+		<a href="#null" onclick="ToggleAll('hide')" id="all_d" title="collaps channel list"<?php echo $style_arrow_down;?>><IMG SRC="icons/arrow.yellow.down.png" name="<?php echo $chan_id;?> down" border="0" alt="arrow down"></a>	
 		Channel List:
 	</td>
 </tr>
@@ -825,8 +841,8 @@ Enter common filter for each channel in 1:1 profile.', this, event, '150px')"><I
 
 <tr class="STATTABLE">
     <td class="STATTABLE" colspan="2">
-		<input name='new_profile_cancel' value='Cancel' type='submit'>
-		<input name='new_profile_commit' value='Create Profile' type='submit'>
+		<input name='new_profile_cancel' value='Cancel' type='submit' onclick='cancelAction=true'>
+		<input name='new_profile_commit' value='Create Profile' type='submit' onclick='cancelAction=false'>
 	</td>
 </tr>
 </table>
@@ -957,7 +973,7 @@ function NewProfileCommit ($profileswitch) {
 		return FALSE;
 	}
 
-	return TRUE;
+	return true;
 
 } // End of NewProfileCommit
 
@@ -1027,6 +1043,9 @@ function Process_stat_tab ($tab_changed, $profile_changed) {
 	
 		// Do the work
 		$cmd_opts['profile'] 	  = $_SESSION['profileswitch'];
+		if ( array_key_exists('pid', $_SESSION ) ) {
+			$cmd_opts['pid'] 	  = $_SESSION['pid'];
+		}
 		$cmd_out = nfsend_query("delete-profile", $cmd_opts, 0);
 		if ( is_array($cmd_out) ) {
 			SetMessage('info', "Profile '" . $cmd_opts['profile'] . "' deleted");
@@ -1043,6 +1062,38 @@ function Process_stat_tab ($tab_changed, $profile_changed) {
 		return;
 	}
 
+	// Cancel building the profile
+	if ( array_key_exists('cancelbuild_x', $_POST ) ) {
+		$parse_opts = array( 
+		"switch" 	=> array( "required" => 1, "default"  => NULL, 
+										  "allow_null" => 0,
+										  "match" => "/^[A-Za-z0-9\.][A-Za-z0-9\-+_\/]+$/" , 
+										  "validate" => "profile_exists_validate",
+										  "must_exist" => 1)
+		);
+		list ($form_data, $has_errors) = ParseForm($parse_opts);
+
+		if ( $has_errors > 0 ) {
+			return;
+		}
+		if ( $form_data['switch'] != $_SESSION['profileswitch'] ) {
+			SetMessage('error', "Profile to delete is not current profile");
+			return;
+		} 
+	
+		// Do the work
+		$cmd_opts['profile']  = $_SESSION['profileswitch'];
+		$cmd_out = nfsend_query("cancel-profile", $cmd_opts, 0);
+		if ( is_array($cmd_out) ) {
+			SetMessage('info', "Building profile '" . $cmd_opts['profile'] . "' canceled");
+			$profiles = GetProfiles();
+			$_SESSION['cancel-inprogress'] = 1;
+		} // else errors are displayed anyway - nothing to do
+
+		$_SESSION['refresh'] = 5;
+		return;
+	}
+
 	// put profile into another group?
 	if ( array_key_exists('regroup', $_POST ) ) {
 		if ( !array_key_exists('groupselect', $_POST ) || !array_key_exists('profilegroup', $_POST )) {
